==> ejc-zjkjcost-impl-3.0.0-20220629.013425-19-sources.jar: com/ejianc/business/zjkjcost/generalApproval/bean/GeneralApprovalEntity.java <==
package com.ejianc.business.zjkjcost.generalApproval.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 总包结算考核奖审批 
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_general_approval")
public class GeneralApprovalEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="basis_content")
    private String basisContent; // 依据
    @TableField(value="settle_cash_mny")
    private BigDecimal settleCashMny; // 总包结算兑现金额
    @TableField(value="project_manager_cash_mny")
    private BigDecimal projectManagerCashMny; // 项目经理兑现金额
    @TableField(value="business_manager_deduction_mny")
    private BigDecimal businessManagerDeductionMny; // 所属单位商务经理扣款金额
    @TableField(value="finance_deduction_mny")
    private BigDecimal financeDeductionMny; // 所属单位财务资金部门扣款金额
    @TableField(value="department_deduction_mny")
    private BigDecimal departmentDeductionMny; // 所属单位建造管理部意见扣款金额
    @TableField(value="technology_deduction_mny")
    private BigDecimal technologyDeductionMny; // 所属单位工程技术中心扣款金额
    @TableField(value="design_deduction_mny")
    private BigDecimal designDeductionMny; // 所属单位设计中心扣款金额
    @TableField(value="leader_cash_mny")
    private BigDecimal leaderCashMny; // 所属单位分管领导兑现金额
    @TableField(value="manager_cash_mny")
    private BigDecimal managerCashMny; // 所属单位总经理兑现金额
    @TableField(value="chairman_cash_mny")
    private BigDecimal chairmanCashMny; // 所属单位董事长兑现金额
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getBasisContent() {
        return basisContent;
    }

    public void setBasisContent(String basisContent) {
        this.basisContent = basisContent;
    }
    public BigDecimal getSettleCashMny() {
        return settleCashMny;
    }

    public void setSettleCashMny(BigDecimal settleCashMny) {
        this.settleCashMny = settleCashMny;
    }
    public BigDecimal getProjectManagerCashMny() {
        return projectManagerCashMny;
    }

    public void setProjectManagerCashMny(BigDecimal projectManagerCashMny) {
        this.projectManagerCashMny = projectManagerCashMny;
    }
    public BigDecimal getBusinessManagerDeductionMny() {
        return businessManagerDeductionMny;
    }

    public void setBusinessManagerDeductionMny(BigDecimal businessManagerDeductionMny) {
        this.businessManagerDeductionMny = businessManagerDeductionMny;
    }
    public BigDecimal getFinanceDeductionMny() {
        return financeDeductionMny;
    }

    public void setFinanceDeductionMny(BigDecimal financeDeductionMny) {
        this.financeDeductionMny = financeDeductionMny;
    }
    public BigDecimal getDepartmentDeductionMny() {
        return departmentDeductionMny;
    }

    public void setDepartmentDeductionMny(BigDecimal departmentDeductionMny) {
        this.departmentDeductionMny = departmentDeductionMny;
    }
    public BigDecimal getTechnologyDeductionMny() {
        return technologyDeductionMny;
    }

    public void setTechnologyDeductionMny(BigDecimal technologyDeductionMny) {
        this.technologyDeductionMny = technologyDeductionMny;
    }
    public BigDecimal getDesignDeductionMny() {
        return designDeductionMny;
    }

    public void setDesignDeductionMny(BigDecimal designDeductionMny) {
        this.designDeductionMny = designDeductionMny;
    }
    public BigDecimal getLeaderCashMny() {
        return leaderCashMny;
    }

    public void setLeaderCashMny(BigDecimal leaderCashMny) {
        this.leaderCashMny = leaderCashMny;
    }
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20221104.030720-88-sources.jar: com/ejianc/business/zjkjcost/generalApproval/bean/GeneralApprovalEntity.java <==
package com.ejianc.business.zjkjcost.generalApproval.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 总包结算考核奖审批 
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_general_approval")
public class GeneralApprovalEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同编号
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="basis_content")
    private String basisContent; // 依据
    @TableField(value="settle_cash_mny")
    private BigDecimal settleCashMny; // 总包结算兑现金额
    @TableField(value="project_manager_cash_mny")
    private BigDecimal projectManagerCashMny; // 项目经理兑现金额
    @TableField(value="business_manager_deduction_mny")
    private BigDecimal businessManagerDeductionMny; // 所属单位商务经理扣款金额
    @TableField(value="finance_deduction_mny")
    private BigDecimal financeDeductionMny; // 所属单位财务资金部门扣款金额
    @TableField(value="department_deduction_mny")
    private BigDecimal departmentDeductionMny; // 所属单位建造管理部意见扣款金额
    @TableField(value="technology_deduction_mny")
    private BigDecimal technologyDeductionMny; // 所属单位工程技术中心扣款金额
    @TableField(value="design_deduction_mny")
    private BigDecimal designDeductionMny; // 所属单位设计中心扣款金额
    @TableField(value="leader_cash_mny")
    private BigDecimal leaderCashMny; // 所属单位分管领导兑现金额
    @TableField(value="manager_cash_mny")
    private BigDecimal managerCashMny; // 所属单位总经理兑现金额
    @TableField(value="chairman_cash_mny")
    private BigDecimal chairmanCashMny; // 所属单位董事长兑现金额


    @TableField(value="count_process")
    private String countProcess; // 计算过程

    public String getCountProcess() {
        return countProcess;
    }

    public void setCountProcess(String countProcess) {
        this.countProcess = countProcess;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getBasisContent() {
        return basisContent;
    }

    public void setBasisContent(String basisContent) {
        this.basisContent = basisContent;
    }
    public BigDecimal getSettleCashMny() {
        return settleCashMny;
    }

    public void setSettleCashMny(BigDecimal settleCashMny) {
        this.settleCashMny = settleCashMny;
    }
    public BigDecimal getProjectManagerCashMny() {
        return projectManagerCashMny;
    }

    public void setProjectManagerCashMny(BigDecimal projectManagerCashMny) {
        this.projectManagerCashMny = projectManagerCashMny;
    }
    public BigDecimal getBusinessManagerDeductionMny() {
        return businessManagerDeductionMny;
    }

    public void setBusinessManagerDeductionMny(BigDecimal businessManagerDeductionMny) {
        this.businessManagerDeductionMny = businessManagerDeductionMny;
    }
    public BigDecimal getFinanceDeductionMny() {
        return financeDeductionMny;
    }

    public void setFinanceDeductionMny(BigDecimal financeDeductionMny) {
        this.financeDeductionMny = financeDeductionMny;
    }
    public BigDecimal getDepartmentDeductionMny() {
        return departmentDeductionMny;
    }

    public void setDepartmentDeductionMny(BigDecimal departmentDeductionMny) {
        this.departmentDeductionMny = departmentDeductionMny;
    }
    public BigDecimal getTechnologyDeductionMny() {
        return technologyDeductionMny;
    }

    public void setTechnologyDeductionMny(BigDecimal technologyDeductionMny) {
        this.technologyDeductionMny = technologyDeductionMny;
    }
    public BigDecimal getDesignDeductionMny() {
        return designDeductionMny;
    }

    public void setDesignDeductionMny(BigDecimal designDeductionMny) {
        this.designDeductionMny = designDeductionMny;
    }
    public BigDecimal getLeaderCashMny() {
        return leaderCashMny;
    }

    public void setLeaderCashMny(BigDecimal leaderCashMny) {
        this.leaderCashMny = leaderCashMny;
    }
    public BigDecimal getManagerCashMny() {
        return managerCashMny;
    }

    public void setManagerCashMny(BigDecimal managerCashMny) {
        this.managerCashMny = managerCashMny;
    }
    public BigDecimal getChairmanCashMny() {
        return chairmanCashMny;
    }

    public void setChairmanCashMny(BigDecimal chairmanCashMny) {
        this.chairmanCashMny = chairmanCashMny;
    }
    
}
